==============================================
Seed Stage-Based Messaging Store documentation
==============================================

The Seed Stage-Based Messaging Store is one of the microservices in the Seed
Stack.

The Stage-Based Messaging Store has the following key responsibilities:

- Store the stage-based content (both audio and text).
- Store the stage-based content schedules.
- Store the stage-based content subscriptions for each user.

Getting started
===============

The following resources are provided to help you get started running or
developing the Seed Stage-Based Messaging Store:

* Learn about the :doc:`Requirements <requirements>` for running the service
  and basic :doc:`Setup <setup>` instructions.
* Read about the :doc:`Data Models <models>` used by the service.
* Read about the :doc:`Authorization <auth>` requirements.
* Browse the :doc:`API Documentation <apis>` for the available endpoints and
  parameters.
* Read about the :doc:`Integrations <integrations>` this service has with the
  other Seed Stack services.
* Learn about what is required when running the service in
  :doc:`Production <production>`
